@@ -111,7 +111,7 @@ def create_xml_file(root_node_tag, output_file):
     return tree
 
 
-def add_new_node(doc, node_tag, att_dict={}, node_text=None, parent_node=None):
+def create_and_add_new_node(parent_node, node_tag, att_dict=None, node_text=None):
     """
     Will add a node to a certain (relative) location
 
@@ -120,8 +120,8 @@ def add_new_node(doc, node_tag, att_dict={}, node_text=None, parent_node=None):
         param parent_node: the parent of the node to add (for root, leave blank)
         param node_tag: the tag of the node ('String', for example)
     """
-    if parent_node is None:
-        parent_node = doc.getroot()
+    if att_dict is None:
+        att_dict = {}
     node = et.SubElement(parent_node, node_tag, att_dict)
     if node_text is not None:
         set_node_text(node, node_text)
